Hypothesis tests
================

Statistical hypothesis tests are used to decide whether data sufficiently
support a particular hypothesis. SciPy defines a number of hypothesis tests,
listed in :ref:`hypotests`.

You can find simple examples to each test in the corresponding docstring. For
more detailed examples, see the following sections.

.. toctree::
    :maxdepth: 1

    hypothesis_bartlett.md
    hypothesis_chisquare.md
    hypothesis_chi2_contingency.md
    hypothesis_dunnett.md
    hypothesis_fisher_exact.md
    hypothesis_fligner.md
    hypothesis_friedmanchisquare.md
    hypothesis_jarque_bera.md
    hypothesis_kendalltau.md
    hypothesis_kurtosistest.md
    hypothesis_levene.md
    hypothesis_normaltest.md
    hypothesis_odds_ratio.md
    hypothesis_pearsonr.md
    hypothesis_shapiro.md
    hypothesis_skewtest.md
    hypothesis_spearmanr.md
